@@ -3,7 +3,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2014-2024 Univention GmbH
+# Copyright 2014-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -87,7 +87,7 @@ class Instance(Base, ProgressMixin):
     PLUGIN_DIR = os.path.dirname(plugins.__file__)
 
     def init(self) -> None:
-        self.modules: dict[str, "Plugin"] = {}
+        self.modules: dict[str, Plugin] = {}
         self.load()
 
     @sanitize(
