@@ -3,7 +3,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2017-2024 Univention GmbH
+# Copyright 2017-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -45,7 +45,7 @@ from OpenSSL import crypto
 
 from univention.config_registry import ucr_live as configRegistry
 from univention.lib.i18n import Translation
-from univention.management.console.modules.diagnostic import MODULE, Critical, Instance, Warning
+from univention.management.console.modules.diagnostic import MODULE, Critical, Instance, Warning  # noqa: A004
 
 
 _ = Translation('univention-management-console-module-diagnostic').translate
