@@ -3,7 +3,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2016-2024 Univention GmbH
+# Copyright 2016-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -35,7 +35,7 @@ from pathlib import Path
 import univention.uldap
 from univention.config_registry import handler_set as ucr_set, ucr_live as ucr
 from univention.lib.i18n import Translation
-from univention.management.console.modules.diagnostic import Critical, Instance, ProblemFixed, Warning
+from univention.management.console.modules.diagnostic import Critical, Instance, ProblemFixed, Warning  # noqa: A004
 
 
 _ = Translation('univention-management-console-module-diagnostic').translate
