@@ -3,7 +3,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2017-2024 Univention GmbH
+# Copyright 2017-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -47,7 +47,7 @@ else:
     SAMBA_AVAILABLE = True
 
 from univention.lib.i18n import Translation
-from univention.management.console.modules.diagnostic import Instance, Warning, util
+from univention.management.console.modules.diagnostic import Instance, Warning, util  # noqa: A004
 
 
 _ = Translation('univention-management-console-module-diagnostic').translate
