@@ -1,6 +1,6 @@
 #!/usr/bin/python3
 #
-# Copyright 2022-2024 Univention GmbH
+# Copyright 2022-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -41,7 +41,7 @@ import univention.config_registry_info as cri
 from univention.config_registry import handler_set as ucr_set, handler_unset as ucr_unset, ucr_live as ucr
 from univention.lib.i18n import Translation
 from univention.management.console.modules.appcenter.util import create_url, scheme_is_http
-from univention.management.console.modules.diagnostic import MODULE, Instance, ProblemFixed, Warning, main
+from univention.management.console.modules.diagnostic import MODULE, Instance, ProblemFixed, Warning, main  # noqa: A004
 
 
 _ = Translation('univention-management-console-module-diagnostic').translate
