@@ -3,7 +3,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2023-2024 Univention GmbH
+# Copyright 2023-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -34,7 +34,7 @@ import subprocess
 from shutil import which
 
 from univention.lib.i18n import Translation
-from univention.management.console.modules.diagnostic import MODULE, Instance, Warning
+from univention.management.console.modules.diagnostic import MODULE, Instance, Warning  # noqa: A004
 
 
 _ = Translation('univention-management-console-module-diagnostic').translate
