@@ -3,7 +3,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2024 Univention GmbH
+# Copyright 2024-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -39,7 +39,7 @@ from shutil import which
 from univention.admin import uldap
 from univention.config_registry import ucr_live as ucr
 from univention.lib.i18n import Translation
-from univention.management.console.modules.diagnostic import Instance, ProblemFixed, Warning
+from univention.management.console.modules.diagnostic import Instance, ProblemFixed, Warning  # noqa: A004
 
 
 _ = Translation('univention-management-console-module-diagnostic').translate
